@@ -48,7 +48,6 @@ use constant TEMPDIR     => EBox::Config->tmp(); # "/tmp/";
 use constant OPENSSLPATH => "/usr/bin/openssl";
 
 use constant CATOPDIR => EBox::Config->home() . "CA/";
-# "/home/quique/my-stuff/openssl-tests/demoCA/";
 
 use constant SSLCONFFILE => EBox::Config->conf() . "openssl.cnf";
 # CATOPDIR . "../openssl.cnf";
@@ -74,6 +73,7 @@ use constant CAPUBKEY    => KEYSDIR . "capubkey.pem";
 
 # Directory mode to allow only owner and readable from others
 use constant DIRMODE     => 00705;
+use constant PRIVATEDIRMODE     => 00700;
 
 # Use Certification Version 3
 use constant EXTENSIONS_V3 => "1";
@@ -172,8 +172,8 @@ sub isCreated
   {
     my ($self, $name) = @_;
 
-    my $retValue = (-d CATOPDIR) and (-f CACERT) and (-f CAPRIVKEY)
-      and (-f CAPUBKEY);
+    my $retValue = ((-d CATOPDIR) and (-f CACERT) and (-f CAPRIVKEY)
+      and (-f CAPUBKEY));
 
     return $retValue;
 
@@ -222,7 +222,7 @@ sub createCA {
     mkdir (CRLDIR, DIRMODE);
     mkdir (NEWCERTSDIR, DIRMODE);
     mkdir (KEYSDIR, DIRMODE);
-    mkdir (PRIVDIR, DIRMODE);
+    mkdir (PRIVDIR, PRIVATEDIRMODE);
     mkdir (REQDIR, DIRMODE);
     # Create index and crl number
     open ( my $OUT, ">" . INDEXFILE);
@@ -1575,6 +1575,8 @@ sub currentCACertificateState
 
     my $serialCert = $self->_obtain(CACERT, 'serial');
 
+    return '!' unless (defined($serialCert));
+
     my $certRef = $self->getCertificateMetadata(serialNumber => $serialCert);
 
     if ( not defined($certRef) ) {
